==> banshee-1-0.98.3.tar.bz2: banshee-1-0.98.3/src/Libraries/Migo/Migo/Migo.Syndication/EventArgs/FeedItemEventArgs.cs <==
/***************************************************************************
 *  FeedItemEventArgs.cs
 *
 *  Copyright (C) 2007 Michael C. Urbanski
 *  Written by Mike Urbanski <michael.c.urbanski@gmail.com>
 ****************************************************************************/

/*  THIS FILE IS LICENSED UNDER THE MIT LICENSE AS OUTLINED IMMEDIATELY BELOW: 
 *
 *  Permission is hereby granted, free of charge, to any person obtaining a
 *  copy of this software and associated documentation files (the "Software"),  
 *  to deal in the Software without restriction, including without limitation  
 *  the rights to use, copy, modify, merge, publish, distribute, sublicense,  
 *  and/or sell copies of the Software, and to permit persons to whom the  
 *  Software is furnished to do so, subject to the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included in 
 *  all copies or substantial portions of the Software.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
 *  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE 
 *  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
 *  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
 *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
 *  DEALINGS IN THE SOFTWARE.
 */
 
using System;
using System.Collections.Generic;

namespace Migo.Syndication
{    
    public class FeedItemEventArgs : FeedEventArgs
    {
        private readonly IFeedItem item;
        private readonly IEnumerable<IFeedItem> items;
        
        public IFeedItem Item
        {
            get { return item; }
        }
        
        public IEnumerable<IFeedItem> Items
        {
            get { return items; }   
        }
        
        public FeedItemEventArgs (IFeed feed, IFeedItem item) : this (feed, item, null) 
        {
            if (item == null) {
            	throw new ArgumentNullException ("item");
            }        
        }
        
        public FeedItemEventArgs (IFeed feed, IEnumerable<IFeedItem> items) : this (feed, null, items) 
        {
            if (items == null) {
            	throw new ArgumentNullException ("items");
            }        
        }
        
        private FeedItemEventArgs (IFeed feed, 
                                   IFeedItem item, 
                                   IEnumerable<IFeedItem> items) : base (feed)
        {
            this.item = item;
            this.items = items;
        }
    }
}

==> banshee-1-0.99.1.tar.bz2: banshee-1-0.99.1/src/Libraries/Migo/Migo/Migo.Syndication/EventArgs/FeedItemEventArgs.cs <==
/***************************************************************************
 *  FeedItemEventArgs.cs
 *
 *  Copyright (C) 2007 Michael C. Urbanski
 *  Written by Mike Urbanski <michael.c.urbanski@gmail.com>
 ****************************************************************************/

/*  THIS FILE IS LICENSED UNDER THE MIT LICENSE AS OUTLINED IMMEDIATELY BELOW: 
 *
 *  Permission is hereby granted, free of charge, to any person obtaining a
 *  copy of this software and associated documentation files (the "Software"),  
 *  to deal in the Software without restriction, including without limitation  
 *  the rights to use, copy, modify, merge, publish, distribute, sublicense,  
 *  and/or sell copies of the Software, and to permit persons to whom the  
 *  Software is furnished to do so, subject to the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included in 
 *  all copies or substantial portions of the Software.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
 *  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE 
 *  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
 *  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
 *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
 *  DEALINGS IN THE SOFTWARE.
 */
 
using System;
using System.Collections.Generic;

namespace Migo.Syndication
{    
    public class FeedItemEventArgs : FeedEventArgs
    {
        private readonly FeedItem item;
        private readonly IEnumerable<FeedItem> items;
        
        public FeedItem Item {
            get { return item; }
        }
        
        public IEnumerable<FeedItem> Items {
            get { return items; }   
        }
        
        public FeedItemEventArgs (Feed feed, FeedItem item) : this (feed, item, null) 
        {
            if (item == null) {
            	throw new ArgumentNullException ("item");
            }        
        }
        
        public FeedItemEventArgs (Feed feed, IEnumerable<FeedItem> items) : this (feed, null, items) 
        {
            if (items == null) {
            	throw new ArgumentNullException ("items");
            }        
        }
        
        private FeedItemEventArgs (Feed feed, 
                                   FeedItem item, 
                                   IEnumerable<FeedItem> items) : base (feed)
        {
            this.item = item;
            this.items = items;
        }
    }
}
